#[repr(transparent)]pub struct Dllcr(pub u32);Expand description
DLL Control Register 0
Tuple Fields
0: u32Implementations
Sourceimpl Dllcr
impl Dllcr
Sourcepub const fn dllreset(&self) -> bool
pub const fn dllreset(&self) -> bool
Software could force a reset on DLL by setting this field to 0x1. This will cause the DLL to lose lock and re-calibrate to detect an ref_clock half period phase shift. The reset action is edge triggered, so software need to clear this bit after set this bit (no delay limitation).
Sourcepub const fn set_dllreset(&mut self, val: bool)
pub const fn set_dllreset(&mut self, val: bool)
Software could force a reset on DLL by setting this field to 0x1. This will cause the DLL to lose lock and re-calibrate to detect an ref_clock half period phase shift. The reset action is edge triggered, so software need to clear this bit after set this bit (no delay limitation).
Sourcepub const fn slvdlytarget(&self) -> u8
pub const fn slvdlytarget(&self) -> u8
The delay target for slave delay line is: ((SLVDLYTARGET+1) * 1/32 * clock cycle of reference clock (serial root clock). If serial root clock is >= 100 MHz, DLLEN set to 0x1, OVRDEN set to =0x0, then SLVDLYTARGET setting of 0xF is recommended.
Sourcepub const fn set_slvdlytarget(&mut self, val: u8)
pub const fn set_slvdlytarget(&mut self, val: u8)
The delay target for slave delay line is: ((SLVDLYTARGET+1) * 1/32 * clock cycle of reference clock (serial root clock). If serial root clock is >= 100 MHz, DLLEN set to 0x1, OVRDEN set to =0x0, then SLVDLYTARGET setting of 0xF is recommended.
Sourcepub const fn ovrden(&self) -> bool
pub const fn ovrden(&self) -> bool
Slave clock delay line delay cell number selection override enable.
Sourcepub const fn set_ovrden(&mut self, val: bool)
pub const fn set_ovrden(&mut self, val: bool)
Slave clock delay line delay cell number selection override enable.
Sourcepub const fn ovrdval(&self) -> u8
pub const fn ovrdval(&self) -> u8
Slave clock delay line delay cell number selection override value.
Sourcepub const fn set_ovrdval(&mut self, val: u8)
pub const fn set_ovrdval(&mut self, val: u8)
Slave clock delay line delay cell number selection override value.