nxp-pac

Crates

git

Versions

mimxrt685s_cm33

Flavors

Flshcr2

Struct Flshcr2 

#[repr(transparent)]
pub struct Flshcr2(pub u32);
Flash Control Register 2

Tuple Fields

0: u32

Implementations

Source

impl Flshcr2

pub const fn ardseqid(&self) -> u8

Sequence Index for AHB Read triggered Command in LUT.

pub const fn set_ardseqid(&mut self, val: u8)

Sequence Index for AHB Read triggered Command in LUT.

pub const fn ardseqnum(&self) -> u8

Sequence Number for AHB Read triggered Command in LUT.

pub const fn set_ardseqnum(&mut self, val: u8)

Sequence Number for AHB Read triggered Command in LUT.

pub const fn awrseqid(&self) -> u8

Sequence Index for AHB Write triggered Command.

pub const fn set_awrseqid(&mut self, val: u8)

Sequence Index for AHB Write triggered Command.

pub const fn awrseqnum(&self) -> u8

Sequence Number for AHB Write triggered Command.

pub const fn set_awrseqnum(&mut self, val: u8)

Sequence Number for AHB Write triggered Command.

pub const fn awrwait(&self) -> u16

For certain devices (such as FPGA), it need some time to write data into internal memory after the command sequences finished on FlexSPI interface

pub const fn set_awrwait(&mut self, val: u16)

For certain devices (such as FPGA), it need some time to write data into internal memory after the command sequences finished on FlexSPI interface

pub const fn awrwaitunit(&self) -> Awrwaitunit

AWRWAIT unit

pub const fn set_awrwaitunit(&mut self, val: Awrwaitunit)

AWRWAIT unit

pub const fn clrinstrptr(&self) -> bool

Clear the instruction pointer which is internally saved pointer by JMP_ON_CS. Refer Programmable Sequence Engine for details.

pub const fn set_clrinstrptr(&mut self, val: bool)

Clear the instruction pointer which is internally saved pointer by JMP_ON_CS. Refer Programmable Sequence Engine for details.