#[repr(transparent)]pub struct Mcr0(pub u32);Expand description
Module Control Register 0
Tuple Fields
0: u32Implementations
Sourceimpl Mcr0
impl Mcr0
Sourcepub const fn set_swreset(&mut self, val: bool)
pub const fn set_swreset(&mut self, val: bool)
Software Reset
Sourcepub const fn set_rxclksrc(&mut self, val: Rxclksrc)
pub const fn set_rxclksrc(&mut self, val: Rxclksrc)
Sample Clock source selection for Flash Reading
Sourcepub const fn serclkdiv(&self) -> Serclkdiv
pub const fn serclkdiv(&self) -> Serclkdiv
The serial root clock could be divided inside FlexSPI wrapper. Refer Clocks chapter for more details on clocking.
Sourcepub const fn set_serclkdiv(&mut self, val: Serclkdiv)
pub const fn set_serclkdiv(&mut self, val: Serclkdiv)
The serial root clock could be divided inside FlexSPI wrapper. Refer Clocks chapter for more details on clocking.
Sourcepub const fn set_dozeen(&mut self, val: Dozeen)
pub const fn set_dozeen(&mut self, val: Dozeen)
Doze mode enable bit
Sourcepub const fn sckfreerunen(&self) -> Sckfreerunen
pub const fn sckfreerunen(&self) -> Sckfreerunen
This bit is used to force SCLK output free-running. For FPGA applications, external device may use SCLK as reference clock to its internal PLL. If SCLK free-running is enabled, data sampling with loopback clock from SCLK pad is not supported (MCR0[RXCLKSRC]=2).
Sourcepub const fn set_sckfreerunen(&mut self, val: Sckfreerunen)
pub const fn set_sckfreerunen(&mut self, val: Sckfreerunen)
This bit is used to force SCLK output free-running. For FPGA applications, external device may use SCLK as reference clock to its internal PLL. If SCLK free-running is enabled, data sampling with loopback clock from SCLK pad is not supported (MCR0[RXCLKSRC]=2).
Sourcepub const fn learnen(&self) -> Learnen
pub const fn learnen(&self) -> Learnen
This bit is used to enable/disable data learning feature. When data learning is disabled, the sampling clock phase 0 is always used for RX data sampling even if LEARN instruction is correctly executed.
Sourcepub const fn set_learnen(&mut self, val: Learnen)
pub const fn set_learnen(&mut self, val: Learnen)
This bit is used to enable/disable data learning feature. When data learning is disabled, the sampling clock phase 0 is always used for RX data sampling even if LEARN instruction is correctly executed.
Sourcepub const fn ipgrantwait(&self) -> u8
pub const fn ipgrantwait(&self) -> u8
Time out wait cycle for IP command grant.
Sourcepub const fn set_ipgrantwait(&mut self, val: u8)
pub const fn set_ipgrantwait(&mut self, val: u8)
Time out wait cycle for IP command grant.
Sourcepub const fn ahbgrantwait(&self) -> u8
pub const fn ahbgrantwait(&self) -> u8
Timeout wait cycle for AHB command grant.
Sourcepub const fn set_ahbgrantwait(&mut self, val: u8)
pub const fn set_ahbgrantwait(&mut self, val: u8)
Timeout wait cycle for AHB command grant.