#[repr(transparent)]pub struct Mcr1(pub u32);Expand description
Module Control Register 1
Tuple Fields
0: u32Implementations
Sourceimpl Mcr1
impl Mcr1
Sourcepub const fn ahbbuswait(&self) -> u16
pub const fn ahbbuswait(&self) -> u16
AHB Read/Write access to Serial Flash Memory space will timeout if not data received from Flash or data not transmitted after AHBBUSWAIT * 1024 ahb clock cycles, AHB Bus will get an error response
Sourcepub const fn set_ahbbuswait(&mut self, val: u16)
pub const fn set_ahbbuswait(&mut self, val: u16)
AHB Read/Write access to Serial Flash Memory space will timeout if not data received from Flash or data not transmitted after AHBBUSWAIT * 1024 ahb clock cycles, AHB Bus will get an error response
Sourcepub const fn seqwait(&self) -> u16
pub const fn seqwait(&self) -> u16
Command Sequence Execution will timeout and abort after SEQWAIT * 1024 Serial Root Clock cycles
Sourcepub const fn set_seqwait(&mut self, val: u16)
pub const fn set_seqwait(&mut self, val: u16)
Command Sequence Execution will timeout and abort after SEQWAIT * 1024 Serial Root Clock cycles