#[repr(transparent)]pub struct Sts0(pub u32);Expand description
Status Register 0
Tuple Fields
0: u32Implementations
Sourceimpl Sts0
impl Sts0
Sourcepub const fn seqidle(&self) -> bool
pub const fn seqidle(&self) -> bool
This status bit indicates the state machine in SEQ_CTL is idle and there is command sequence executing on FlexSPI interface.
Sourcepub const fn set_seqidle(&mut self, val: bool)
pub const fn set_seqidle(&mut self, val: bool)
This status bit indicates the state machine in SEQ_CTL is idle and there is command sequence executing on FlexSPI interface.
Sourcepub const fn arbidle(&self) -> bool
pub const fn arbidle(&self) -> bool
This status bit indicates the state machine in ARB_CTL is busy and there is command sequence granted by arbitrator and not finished yet on FlexSPI interface. When ARB_CTL state (ARBIDLE=0x1) is idle, there will be no transaction on FlexSPI interface also (SEQIDLE=0x1). So this bit should be polled to wait for FlexSPI controller become idle instead of SEQIDLE.
Sourcepub const fn set_arbidle(&mut self, val: bool)
pub const fn set_arbidle(&mut self, val: bool)
This status bit indicates the state machine in ARB_CTL is busy and there is command sequence granted by arbitrator and not finished yet on FlexSPI interface. When ARB_CTL state (ARBIDLE=0x1) is idle, there will be no transaction on FlexSPI interface also (SEQIDLE=0x1). So this bit should be polled to wait for FlexSPI controller become idle instead of SEQIDLE.
Sourcepub const fn arbcmdsrc(&self) -> Arbcmdsrc
pub const fn arbcmdsrc(&self) -> Arbcmdsrc
This status field indicates the trigger source of current command sequence granted by arbitrator. This field value is meaningless when ARB_CTL is not busy (STS0[ARBIDLE]=0x1).
Sourcepub const fn set_arbcmdsrc(&mut self, val: Arbcmdsrc)
pub const fn set_arbcmdsrc(&mut self, val: Arbcmdsrc)
This status field indicates the trigger source of current command sequence granted by arbitrator. This field value is meaningless when ARB_CTL is not busy (STS0[ARBIDLE]=0x1).
Sourcepub const fn datalearnphasea(&self) -> u8
pub const fn datalearnphasea(&self) -> u8
Indicate the sampling clock phase selection on Port A after Data Learning.
Sourcepub const fn set_datalearnphasea(&mut self, val: u8)
pub const fn set_datalearnphasea(&mut self, val: u8)
Indicate the sampling clock phase selection on Port A after Data Learning.
Sourcepub const fn datalearnphaseb(&self) -> u8
pub const fn datalearnphaseb(&self) -> u8
Indicate the sampling clock phase selection on Port B after Data Learning.
Sourcepub const fn set_datalearnphaseb(&mut self, val: u8)
pub const fn set_datalearnphaseb(&mut self, val: u8)
Indicate the sampling clock phase selection on Port B after Data Learning.